<?php

// Copy this to the docroot downloads folder for dir listing
// Then, create symlinks to this file from other folders.
// Add items to the $ignore array as needed.

$dir = './';
$all_files = scandir($dir);
$root = false;

$self = filter_input(INPUT_SERVER, 'PHP_SELF', FILTER_SANITIZE_URL);

if (dirname($self) == '/downloads') {
    $root = true;
}


$dirs = [];
$files = [];

$ignore = [
    'index.php',
    'Thumbs.db',
    'fires',
    'greenup',
    'pcuring',
    'gridq'
];

if (! $root) {
    $dirs[] = '../';
}

foreach ($all_files as $file) {
    if (is_dir($file) && substr($file, 0, 1) != '.' && ! in_array($file, $ignore)) {
        $dirs[] = $file;
    } else {
        if (substr($file, 0, 1) != '.' && ! in_array($file, $ignore)) {
            $files[] = $file;
        }
    }
}


function getFileSize($bytes) {

    if ($bytes >= pow(1024, 4)) {
       $size = round($bytes / pow(1024, 4), 2);
       $suffix = "TB";
    }
    elseif ($bytes >= pow(1024, 3)) {
       $size = round($bytes / pow(1024, 3), 2);
       $suffix = "GB";
    }
    elseif ($bytes >= pow(1024, 2)) {
       $size = round($bytes / pow(1024, 2), 2);
       $suffix = "MB";
    }
    elseif ($bytes >= 1024) {
       $size = round($bytes / 1024, 2);
       $suffix = "KB";
    }
    else {
       $size = $bytes;
       $suffix = "B";
    }
    $size .= " " . $suffix;

    return $size;

}
?>

<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8" />
        <title>Index of <?php echo dirname($self); ?></title>
        <style>
            body {
                font-family: Verdana; sans-serif;
                font-size: 80%;
            }
            table {
                border-collapse: collapse;
                min-width: 600px;
            }
            th, td {
                border-bottom: 1px solid #ddd;
                text-align: left;
                padding: 10px;
            }
            tr:hover {
                background-color: #f5f5f5;
            }
            td.file {
                width: 50%;
                padding-left: 30px;
            }
            td.size {
                text-align: right;
            }
            td.dir {
                font-weight: bold;
                background-image: url('/icons/folder.gif');
                background-repeat: no-repeat;
                background-position: left;
                padding-left: 30px;
            }
        </style>
    </head>
    <body>
    <h1>Index of <?php echo dirname($self); ?></h1>
    <table>
        <thead>
            <tr>
                <th>Name</th>
                <th>Modified</th>
                <th>Size</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($dirs as $dir) : ?>
            <tr>
                <td class="dir"><a href="<?php echo $dir; ?>"><?php echo $dir; ?></a></td>
                <td class="date"></td>
                <td class="size"></td>
            <tr>
            <?php endforeach; ?>
            </tr>
            <?php foreach ($files as $file) : ?>
            <tr>
                <td class="file"><a href="<?php echo $file; ?>"><?php echo $file; ?></a></td>
                <td class="date"><?php echo date('Y-m-d H:i:s', filemtime($file)); ?></td>
                <td class="size"><?php echo getFileSize(filesize($file)); ?></td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
    </body>
</html>

